@@ -24,7 +24,7 @@ __all__ = [
     "run_default_task",
 ]
 
-__version__ = "1.1.3"
+__version__ = "1.1.4"
 
 _DEFAULT_STDERR_LOGS = ["metamake.filesystem", "metamake.shell"]
 _all_tasks = {}
@@ -188,11 +188,12 @@ def metamake_bin():
 
     # the user didn't want help, they are actually trying to exec metamake
     import os
-    sys.path.insert(0, os.getcwd())
+    import imp
     import metamake
     
     try:
-        import Makefile
+        makefile_path = os.path.join(os.path.abspath(os.getcwd()), "Makefile.py")
+        imp.load_module("Makefile", open(makefile_path, "r"), makefile_path, ('.py', 'U', 1))
     except ImportError, e:
         
         errmsg = str(e)
@@ -207,7 +208,7 @@ def metamake_bin():
         raise SystemExit(1)
     
     # any commandline argument without a '=' in it is a task that we want to run
-    tasknames = [arg for arg in sys.argv[1:] if "=" not in arg]
+    tasknames = [arg for arg in sys.argv[1:] if "=" not in arg and arg != "--trace"]
     
     # decide what task(s) to run
     if len(tasknames) is 0:
