@@ -89,17 +89,20 @@ def serialize_metamake_to_makefile(makefile_filename):
         "makefile_metamake_bootstrapper.standalone_deserialize_metamake_from_makefile('%s')" % makefile_filename,
     ])
     
+    # this is the old way of importing it by manipulating the path
+    # load_metamake = "sys.path.insert(0, os.getcwd());import Makefile"
+    load_metamake = "import imp;makefile_path=os.path.join(os.path.abspath(os.getcwd()), 'Makefile.py');imp.load_module('Makefile', open(makefile_path, 'r'), makefile_path, ('.py', 'U', 1))"
     new_makefile_file.write('''
 BOOTSTRAPMETAMAKE=%(oneliner)s
 
 __default:
-	@python -c "$(BOOTSTRAPMETAMAKE);import sys;import os;sys.path.insert(0, os.getcwd());import Makefile;import metamake;metamake.run_default_task();"
+	@python -c "$(BOOTSTRAPMETAMAKE);import sys;import os;%(load_metamake)s;import metamake;metamake.run_default_task();"
 
 ls:
-	@python -c "$(BOOTSTRAPMETAMAKE);import sys;import os;sys.path.insert(0, os.getcwd());import Makefile;import metamake;metamake.list_tasks()"
+	@python -c "$(BOOTSTRAPMETAMAKE);import sys;import os;%(load_metamake)s;import metamake;metamake.list_tasks()"
 
 %%:
-	@python -c "$(BOOTSTRAPMETAMAKE);import sys;import os;sys.path.insert(0, os.getcwd());import Makefile;import metamake;metamake.run_task('$@', from_makefile=True)"
+	@python -c "$(BOOTSTRAPMETAMAKE);import sys;import os;%(load_metamake)s;import metamake;metamake.run_task('$@', from_makefile=True)"
 ''' % locals())
     
     # we are done serializing, close the makefile
